#!/bin/bash

#Install OpenLM Broker Service script
echo -e "\e[96mInstall OpenLM Broker Service...\033[0m"

#check OS packages function
checkOSPkg () {
	if [ "$1" == "0" ]
	  then
		if rpm -q $2 > /dev/null 2>&1
			then
			  return "1"
			else
			  return "0"
		fi
      else
		if dpkg -s $2 > /dev/null 2>&1
			then
			  return "1"
			else
			  return "0"
		fi
    fi
}

INSTDIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
SERVICEDEFDIR="/etc/systemd/system"
PKG="systemd"
OSFOUND="0"
SRVPKGINSTALLED="0"
source $INSTDIR/settings.sh
ISBROKERACTIVE="$(systemctl is-active "$BROKERSRVNAME")"
#check if service is installed
if [[ ("$ISBROKERACTIVE" != "unknown") && ("$ISBROKERACTIVE" != "inactive") ]]
  then
    echo "OpenLM Broker Service $BROKERSRVNAME is already installed! Customize edit service_name.sh if you want to install another instance."
    exit
fi

#check Linux/Unix OS services packages
echo "Check OS service $PKG package..."
#Red Hat/Fedora/CentOS/Suse Linux
if hash rpm > /dev/null 2>&1
	then
		if hash yum > /dev/null 2>&1
		  then
			  OSFOUND="1"
			  checkOSPkg "0" "$PKG"
			  SRVPKGINSTALLED=$?
			  if [ "$SRVPKGINSTALLED" == "0" ]
				then
				  yum install $PKG
				  checkOSPkg 0 "$PKG"
				  SRVPKGINSTALLED=$?
			  fi
		fi
fi
#Debian / Ubuntu
if [ "$OSFOUND" == "0" ]
  then
	if hash dpkg > /dev/null 2>&1
		then
			if hash apt-get > /dev/null 2>&1
			  then
				OSFOUND="1"
				checkOSPkg "1" "$PKG"
				SRVPKGINSTALLED=$?
				if dpkg -s $PKG > /dev/null 2>&1
				  then
					  apt-get install $PKG
					  checkOSPkg 1 "$PKG"
					  SRVPKGINSTALLED=$?
				fi
			fi
	fi
fi
if [ "$SRVPKGINSTALLED" == "1" ]
  then
    echo "$PKG package is installed."
  else
    echo "$PKG package is not installed. Please ask support to OS admin."
    exit
fi
echo "Configuring service..."
cat >> $BROKERSRVNAMEFILE <<EOF
[Unit]
Description=OpenLMBrokerScript
After=sysinit.target

[Service]
ExecStart=/bin/bash $INSTDIR/run_broker.sh
Type=forking
User=$BROKERSRVNAMEUSER

[Install]
WantedBy=multi-user.target

EOF
chmod ug=rw,o=r $INSTDIR/$BROKERSRVNAMEFILE
mv $INSTDIR/$BROKERSRVNAMEFILE $SERVICEDEFDIR/$BROKERSRVNAMEFILE
systemctl daemon-reload
systemctl enable $BROKERSRVNAME
systemctl reset-failed
systemctl start $BROKERSRVNAME
echo -e "\e[96mOpenLM Broker Service is installed and started!\033[0m"
